@@ -1,14 +1,14 @@
 package VIC::PIC::P18LF13K50;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 $VERSION = eval $VERSION;
 use Moo;
 extends 'VIC::PIC::P18F13K50';
 
 # role CodeGen
-has type => (is => 'ro', default => 'p18f13k50');
-has include => (is => 'ro', default => 'p18f13k50.inc');
+has type => (is => 'ro', default => 'p18lf13k50');
+has include => (is => 'ro', default => 'p18lf13k50.inc');
 1;
 
 __END__
