@@ -1,14 +1,14 @@
 package VIC::PIC::P18LF14K50;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 $VERSION = eval $VERSION;
 use Moo;
 extends 'VIC::PIC::P18F14K50';
 
 # role CodeGen
-has type => (is => 'ro', default => 'p18f14k50');
-has include => (is => 'ro', default => 'p18f14k50.inc');
+has type => (is => 'ro', default => 'p18lf14k50');
+has include => (is => 'ro', default => 'p18lf14k50.inc');
 1;
 
 __END__
